@@ -2,6 +2,11 @@ from django import template
 
 register = template.Library()
 
+class_converter = {
+    "textinput":"textinput textInput",
+    "fileinput":"fileinput fileUpload"
+}
+
 @register.filter
 def is_checkbox(field):
     return field.field.widget.__class__.__name__.lower() == "checkboxinput"
@@ -9,9 +14,11 @@ def is_checkbox(field):
 @register.filter
 def with_class(field):
     class_name = field.field.widget.__class__.__name__.lower()
-    try:
-        field.field.widget.attrs['class'] += class_name
-    except KeyError:
+    class_name = class_converter.get(class_name, class_name)
+    if "class" in field.field.widget.attrs:
+        field.field.widget.attrs['class'] += " %s" % class_name
+    else:
         field.field.widget.attrs['class'] = class_name
     return unicode(field)
 
+
